===========================
collective.js.iframeresizer
===========================
   
Plone integration of iframe-resizer (http://davidjbradshaw.github.io/iframe-resizer/)

Using version 3.5.12 (2017-03-29)
